@@ -8,6 +8,9 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
+# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
+# directory of this distribution and at
+# <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -522,24 +525,12 @@ sub send_notify_to_user {
         $param->{'to'}   = $user;
         $param->{'type'} = $operation;
 
-        if ($operation eq 'ticket_to_signoff') {
-            $param->{one_time_ticket} =
-                Sympa::Ticket::create($user, $robot_id,
-                'signoff/' . $list->{'name'},
-                $param->{ip})
-                or return undef;
-        } elsif ($operation eq 'ticket_to_family_signoff') {
+        if ($operation eq 'ticket_to_family_signoff') {
             $param->{one_time_ticket} =
                 Sympa::Ticket::create($user, $robot_id,
                 'family_signoff/' . $param->{family} . '/' . $user,
                 $param->{ip})
                 or return undef;
-        } elsif ($operation eq 'ticket_to_send') {
-            $param->{'one_time_ticket'} =
-                Sympa::Ticket::create($user, $robot_id,
-                'change_email/' . $param->{email},
-                $param->{ip})
-                or return undef;
         }
 
         unless (Sympa::send_file($that, 'user_notification', $user, $param)) {
