@@ -559,6 +559,29 @@ our @params = (
         'gettext_comment' =>
             'List of operations separated by comma for which blacklist filter is applied.  Setting this parameter to "none" will hide the blacklist feature.',
     },
+    {   'name'       => 'owner_domain',
+        'sample'     => 'domain1.tld domain2.tld',
+        'gettext_id' => 'List of required domains for list owner addresses',
+        'file'       => 'sympa.conf',
+        'optional'   => '1',
+        'split_char' => ' ',
+        'vhost'      => '1',
+        'edit'       => '1',
+        'gettext_comment' =>
+            'Restrict list ownership to addresses in the specified domains. This can be used to reserve list ownership to a group of trusted users from a set of domains associated with an organization, while allowing editors and subscribers from the Internet at large.',
+        'default'    => undef,
+    },
+    {   'name'       => 'owner_domain_min',
+        'sample'     => '1',
+        'gettext_id' => 'Minimum number of list owners that must match owner_domain restriction',
+        'file'       => 'sympa.conf',
+        'default'    => '0',
+        'optional'   => '1',
+        'vhost'      => '1',
+        'edit'       => '1',
+        'gettext_comment' =>
+            'Minimum number of list owners that must satisfy the owner_domain restriction.  The default of zero (0) means *all* list owners must match. Setting to 1 requires only one list owner to match owner_domain; all other owners can be from any domain. This setting can be used to ensure that there is always at least one known contact point for a mailing list.',
+    },
 
     {'gettext_id' => 'Archives'},
 
@@ -1263,14 +1286,6 @@ our @params = (
         'file' => 'wwsympa.conf',
         'edit' => '1',
     },
-    {   'name'       => 'use_fast_cgi',
-        'default'    => '1',
-        'gettext_id' => 'Enable FastCGI',
-        'file'       => 'wwsympa.conf',
-        'edit'       => '1',
-        'gettext_comment' =>
-            'Is FastCGI module for HTTP server installed. This module provide much faster web interface.',
-    },
 
     {'gettext_id' => 'Web interface parameters: Appearances'},
 
@@ -2009,14 +2024,23 @@ our @params = (
         'file'    => 'sympa.conf',
         'default' => '300',
     },
-    {   'name'    => 'voot_feature',
+    {   'name'    => 'voot_feature', # Not implemented yet.
         'default' => 'off',
         'file'    => 'sympa.conf',
     },
+
     {   'name'    => 'edit_list',                #FIXME:maybe not used
         'default' => 'owner',
         'file'    => 'sympa.conf',
     },
+    {   'name'       => 'use_fast_cgi',
+        'default'    => '1',
+        'gettext_id' => 'Enable FastCGI',
+        'file'       => 'wwsympa.conf',
+        'edit'       => '1',
+        'gettext_comment' =>
+            'Is FastCGI module for HTTP server installed. This module provide much faster web interface.',
+    },
 
 ## Not implemented yet.
 ##    {
