@@ -72,6 +72,7 @@ sub _new {
     return bless {%params} => $class;
 }
 
+# Note: uri() method need perl-ldap >= 0.34.
 sub _connect {
     my $self = shift;
 
@@ -81,19 +82,6 @@ sub _connect {
             $log->syslog('err', 'Can\'t load IO::Socket::SSL');
             return undef;
         }
-
-        # Earlier releases of IO::Socket::SSL would fallback SSL_verify_mode
-        # to SSL_VERIFY_NONE when there are no usable CAfile nor CApath.
-        # However, recent releases won't: They simply deny connection.
-        # As a workaround, make ca_file or ca_path parameter mandatory unless
-        # "none" is explicitly assigned to ca_verify parameter.
-        unless ($self->{ca_verify} and $self->{ca_verify} eq 'none') {
-            unless ($self->{ca_file} or $self->{ca_path}) {
-                $log->syslog('err',
-                    'Neither ca_file nor ca_path parameter is specified');
-                return undef;
-            }
-        }
     }
 
     # new() with multiple alternate hosts needs perl-ldap >= 0.27.
@@ -105,8 +93,8 @@ sub _connect {
             : ($self->{ca_verify} eq 'required') ? 'require'
             :                                      $self->{ca_verify}
         ),
-        capath     => $self->{'ca_path'},
-        cafile     => $self->{'ca_file'},
+        ($self->{'ca_path'} ? (capath => $self->{'ca_path'}) : ()),
+        ($self->{'ca_file'} ? (cafile => $self->{'ca_file'}) : ()),
         sslversion => $self->{'ssl_version'},
         ciphers    => $self->{'ssl_ciphers'},
         clientcert => $self->{'ssl_cert'},
@@ -121,9 +109,6 @@ sub _connect {
         return undef;
     }
 
-    # scheme() and uri() need perl-ldap >= 0.34.
-    my $host_entry = sprintf '%s://%s', $connection->scheme, $connection->uri;
-
     # START_TLS if requested.
     if ($self->{use_tls} eq 'starttls') {
         my $mesg = $connection->start_tls(
@@ -132,8 +117,8 @@ sub _connect {
                 : ($self->{ca_verify} eq 'required') ? 'require'
                 :                                      $self->{ca_verify}
             ),
-            capath     => $self->{'ca_path'},
-            cafile     => $self->{'ca_file'},
+            ($self->{'ca_path'} ? (capath => $self->{'ca_path'}) : ()),
+            ($self->{'ca_file'} ? (cafile => $self->{'ca_file'}) : ()),
             sslversion => $self->{'ssl_version'},
             ciphers    => $self->{'ssl_ciphers'},
             clientcert => $self->{'ssl_cert'},
@@ -149,7 +134,7 @@ sub _connect {
                 $self->{_error_string} = 'Unknown';
             }
             $log->syslog('err', 'Failed to start TLS with LDAP server %s: %s',
-                $host_entry, $self->error);
+                $connection->uri, $self->error);
             $connection->unbind;
             return undef;
         }
@@ -175,11 +160,11 @@ sub _connect {
             $self->{_error_string} = 'Unknown';
         }
         $log->syslog('err', 'Failed to bind to LDAP server %s: %s',
-            $host_entry, $self->error);
+            $connection->uri, $self->error);
         $connection->unbind;
         return undef;
     }
-    $log->syslog('debug3', 'Bound to LDAP host "%s"', $host_entry);
+    $log->syslog('debug3', 'Bound to LDAP host "%s"', $connection->uri);
 
     delete $self->{_error_code};
     delete $self->{_error_string};
