@@ -47,20 +47,19 @@ use Term::ProgressBar;
 use XML::LibXML;
 
 use Sympa;
-use Sympa::Admin;
+use Sympa::Aliases;
 use Conf;
 use Sympa::Config_XML;
-use Sympa::Constants;
 use Sympa::DatabaseManager;
-use Sympa::Language;
 use Sympa::List;
+use Sympa::LockedFile;
 use Sympa::Log;
 use Sympa::Regexps;
-use Sympa::Scenario;
+use Sympa::Spindle::ProcessRequest;
+use Sympa::Template;
 use Sympa::Tools::File;
 
-my $language = Sympa::Language->instance;
-my $log      = Sympa::Log->instance;
+my $log = Sympa::Log->instance;
 
 my %list_of_families;
 my @uncompellable_param = (
@@ -272,177 +271,8 @@ sub new {
     return $self;
 }
 
-=pod 
-
-=head2 sub add_list(FILE_HANDLE $data, BOOLEAN $abort_on_error)
-
-Adds a list to the family. List description can be passed either through a hash of data or through a file handle.
-
-=head3 Arguments 
-
-=over 
-
-=item * I<$self>, the Sympa::Family object,
-
-=item * I<$data>, a file handle on an XML B<list> description file or a hash of data,
-
-=item * I<$abort_on_error>: if true, the function won't create lists in status error_config.
-
-=back 
-
-=head3 Return 
-
-=over 
-
-=item * I<$return>, a hash containing the execution state of the method. If everything went well, the "ok" key must be associated to the value "1".
-
-=back 
-
-=cut
-
-#########################################
-# add_list
-#########################################
-# add a list to the family under to current robot:
-# (list described by the xml file)
-#
-# IN : -$self
-#      -$data : file handle on an xml file or hash of data
-#      -$abort_on_error : if true won't create list in status error_config
-# OUT : -$return->{'ok'} = 1(pas d'erreur fatale) or undef(erreur fatale)
-#       -$return->{'string'} : string of results
-#########################################
-sub add_list {
-    my ($self, $data, $abort_on_error) = @_;
-
-    $log->syslog('info', '(%s)', $self->{'name'});
-
-    $self->{'state'} = 'no_check';
-    my $return;
-    $return->{'ok'}           = undef;
-    $return->{'string_info'}  = undef;    ## info and simple errors
-    $return->{'string_error'} = undef;    ## fatal errors
-
-    my $hash_list;
-
-    if (ref($data) eq "HASH") {
-        $hash_list = {config => $data};
-    } else {
-        #copy the xml file in another file
-        unless (open FIC, '>', $self->{'dir'} . '/_new_list.xml') {
-            $log->syslog('err',
-                'Impossible to create the temp file %s/_new_list.xml: %m',
-                $self->{'dir'});
-        }
-        while (<$data>) {
-            print FIC ($_);
-        }
-        close FIC;
-
-        # get list data
-        open(FIC, '<:raw', $self->{'dir'} . '/_new_list.xml');
-        my $config = Sympa::Config_XML->new(\*FIC);
-        close FIC;
-        unless (defined $config->createHash()) {
-            push @{$return->{'string_error'}},
-                "Error in representation data with these xml data";
-            return $return;
-        }
-
-        $hash_list = $config->getHash();
-    }
-
-    # Check length
-    if (Sympa::Constants::LIST_LEN() <
-        length($hash_list->{'config'}{'listname'})) {
-        $log->syslog('err', 'Too long value of param "listname"');
-        push @{$return->{'string_error'}}, 'Too long list name';
-        return $return;
-    }
-
-    #list creation
-    my $result = Sympa::Admin::create_list($hash_list->{'config'},
-        $self, $self->{'robot'}, $abort_on_error);
-    unless (defined $result) {
-        push @{$return->{'string_error'}},
-            "Error during list creation, see logs for more information";
-        return $return;
-    }
-    unless (defined $result->{'list'}) {
-        push @{$return->{'string_error'}},
-            "Errors : no created list, see logs for more information";
-        return $return;
-    }
-    my $list = $result->{'list'};
-
-    ## aliases
-    if ($result->{'aliases'} == 1) {
-        push @{$return->{'string_info'}},
-            "List $list->{'name'} has been created in $self->{'name'} family";
-    } else {
-        push @{$return->{'string_info'}},
-            "List $list->{'name'} has been created in $self->{'name'} family, required aliases : $result->{'aliases'} ";
-    }
-
-    # config_changes
-    unless (open FILE, '>', "$list->{'dir'}/config_changes") {
-        $list->set_status_error_config('error_copy_file', $self->{'name'});
-        push @{$return->{'string_info'}},
-            'Impossible to create file %s/config_changes : %s, the list is set in status error_config',
-            $list->{'dir'}, $ERRNO;
-    }
-    close FILE;
-
-    # info parameters
-    $list->{'admin'}{'latest_instantiation'}{'email'} =
-        Sympa::get_address($self, 'listmaster');
-    $list->{'admin'}{'latest_instantiation'}{'date_epoch'} = time;
-    $list->save_config(Sympa::get_address($self, 'listmaster'));
-    $list->{'family'} = $self;
-
-    ## check param_constraint.conf
-    $self->{'state'} = 'normal';
-    my $error = $self->check_param_constraint($list);
-    $self->{'state'} = 'no_check';
-
-    unless (defined $error) {
-        $list->set_status_error_config('no_check_rules_family',
-            $self->{'name'});
-        push @{$return->{'string_error'}},
-            "Impossible to check parameters constraint, see logs for more information. The list is set in status error_config";
-        return $return;
-    }
-
-    if (ref($error) eq 'ARRAY') {
-        $list->set_status_error_config('no_respect_rules_family',
-            $self->{'name'});
-        push @{$return->{'string_info'}},
-            "The list does not respect the family rules : "
-            . join(", ", @{$error});
-    }
-
-    ## copy files in the list directory : xml file
-    unless (ref($data) eq "HASH") {
-        unless ($self->_copy_files($list->{'dir'}, "_new_list.xml")) {
-            $list->set_status_error_config('error_copy_file',
-                $self->{'name'});
-            push @{$return->{'string_info'}},
-                "Impossible to copy the xml file in the list directory, the list is set in status error_config.";
-        }
-    }
-
-    ## Synchronize list members if required
-    if ($list->has_include_data_sources()) {
-        $log->syslog('notice', "Synchronizing list members...");
-        $list->sync_include();
-    }
-
-    ## END
-    $self->{'state'} = 'normal';
-    $return->{'ok'}  = 1;
-
-    return $return;
-}
+# Merged to: Sympa::Request::Handler::create_automatic_list::_twist().
+#sub add_list;
 
 =pod 
 
@@ -555,8 +385,7 @@ sub modify_list {
     my $old_status     = $list->{'admin'}{'status'};
 
     ## list config family updating
-    my $result = Sympa::Admin::update_list($list, $hash_list->{'config'},
-        $self, $self->{'robot'});
+    my $result = $self->_update_list($list, $hash_list->{'config'});
     unless (defined $result) {
         $log->syslog('err', 'No object list resulting from updating list %s',
             $list->{'name'});
@@ -628,16 +457,15 @@ sub modify_list {
 
     if ($result->{'aliases'} == 1) {
         push @{$return->{'string_info'}},
-            "The $list->{'name'} list has been modified.";
-
+            sprintf('The %s list has been modified.', $list->{'name'});
     } elsif ($result->{'install_remove'} eq 'install') {
         push @{$return->{'string_info'}},
-            "List $list->{'name'} has been modified, required aliases :\n $result->{'aliases'} ";
-
+            sprintf('List %s has been modified, required aliases.',
+            $list->{'name'});
     } else {
         push @{$return->{'string_info'}},
-            "List $list->{'name'} has been modified, aliases need to be removed : \n $result->{'aliases'}";
-
+            sprintf('List %s has been modified, aliases need to be removed.',
+            $list->{'name'});
     }
 
     ## config_changes
@@ -711,6 +539,132 @@ sub modify_list {
     return $return;
 }
 
+# update a list : used by sympa.pl--instantiate_family
+# with family concept when the list already exists
+#
+# IN  : - $list : the list to update
+#       - $param : ref on parameters of the new
+#          config list with obligatory :
+#         $param->{'listname'}
+#         $param->{'subject'}
+#         $param->{'owner'} (or owner_include):
+#          array of hash,with key email obligatory
+#         $param->{'owner_include'} array of hash :
+#              with key source obligatory
+#       - $self : the family object
+#       - $robot : the list's robot
+#
+# OUT : - $list : the updated list or undef
+#
+# Old name: Sympa::Admin::update_list().
+sub _update_list {
+    $log->syslog('info', '(%s, %s, %s)', @_);
+    my $self  = shift;
+    my $list  = shift;
+    my $param = shift;
+
+    my $robot = $self->{'robot'};
+
+    ## mandatory list parameters
+    foreach my $arg ('listname') {
+        unless ($param->{$arg}) {
+            $log->syslog('err', 'Missing list param %s', $arg);
+            return undef;
+        }
+    }
+
+    ## template file
+    my $template_file = Sympa::search_fullpath($self, 'config.tt2');
+    unless (defined $template_file) {
+        $log->syslog('err', 'No config template from family %s@%s',
+            $self->{'name'}, $robot);
+        return undef;
+    }
+
+    ### Check topics
+    #if (defined $param->{'topics'}) {
+    #    unless (_check_topics($param->{'topics'}, $robot)) {
+    #        $log->syslog('err', 'Topics param %s not defined in topics.conf',
+    #            $param->{'topics'});
+    #    }
+    #}
+
+    ## Lock config before openning the config file
+    my $lock_fh = Sympa::LockedFile->new($list->{'dir'} . '/config', 5, '>');
+    unless ($lock_fh) {
+        $log->syslog('err', 'Impossible to create %s/config: %s',
+            $list->{'dir'}, $ERRNO);
+        return undef;
+    }
+
+    my $template =
+        Sympa::Template->new(undef, include_path => [$self->{'dir'}]);
+    unless ($template->parse($param, 'config.tt2', $lock_fh)) {
+        $log->syslog('err', 'Can\'t parse %s/config.tt2: %s',
+            $self->{'dir'}, $template->{last_error});
+        return undef;
+    }
+    ## Unlock config file
+    $lock_fh->close;
+
+    ## Create list object
+    unless ($list = Sympa::List->new($param->{'listname'}, $robot)) {
+        $log->syslog('err', 'Unable to create list %s', $param->{'listname'});
+        return undef;
+    }
+
+    $list->{'admin'}{'creation'}{'date_epoch'} = time;
+    $list->{'admin'}{'creation'}{'email'}      = $param->{'creation_email'}
+        || Sympa::get_address($robot, 'listmaster');
+    $list->{'admin'}{'status'} = $param->{'status'} || 'open';
+    $list->{'admin'}{'family_name'} = $self->{'name'};
+
+    ## Create associated files if a template was given.
+    my @files_to_parse;
+    foreach my $file (split ',',
+        Conf::get_robot_conf($robot, 'parsed_family_files')) {
+        $file =~ s{\s}{}g;
+        push @files_to_parse, $file;
+    }
+    for my $file (@files_to_parse) {
+        my $template_file = Sympa::search_fullpath($self, $file . ".tt2");
+        if (defined $template_file) {
+            my $file_content;
+
+            my $template =
+                Sympa::Template->new(undef, include_path => [$self->{'dir'}]);
+            my $tt_result =
+                $template->parse($param, $file . ".tt2", \$file_content);
+            unless ($tt_result) {
+                $log->syslog(
+                    'err',
+                    'Template error. List %s from family %s@%s, file %s: %s',
+                    $param->{'listname'},
+                    $self->{'name'},
+                    $robot,
+                    $file,
+                    $template->{last_error}
+                );
+                next;    #FIXME: Abort processing and rollback.
+            }
+            unless (open FILE, '>', "$list->{'dir'}/$file") {
+                $log->syslog('err', 'Impossible to create %s/%s: %s',
+                    $list->{'dir'}, $file, $!);
+            }
+            print FILE $file_content;
+            close FILE;
+        }
+    }
+
+    ## Synchronize list members if required
+    if ($list->has_include_data_sources()) {
+        $log->syslog('notice', "Synchronizing list members...");
+        $list->sync_include();
+    }
+
+    return $list;
+}
+
 =pod 
 
 =head2 sub close_family()
@@ -765,9 +719,15 @@ sub close_family {
             next;
         }
 
-        unless (
-            $list->set_status_family_closed('close_list', $self->{'name'})) {
-            push(@impossible_close, $list->{'name'});
+        my $spindle = Sympa::Spindle::ProcessRequest->new(
+            context          => $self->{'robot'},
+            action           => 'close_list',
+            current_list     => $list,
+            sender           => Sympa::get_address($self, 'listmaster'),
+            scenario_context => {skip => 1},
+        );
+        unless ($spindle and $spindle->spin and $spindle->success) {
+            push @impossible_close, $list->{'name'};
             next;
         }
         push(@close_ok, $list->{'name'});
@@ -954,44 +914,35 @@ sub instantiate {
         } else {
             # FIRST LIST CREATION
 
-            # Check length
-            if (Sympa::Constants::LIST_LEN() <
-                length($hash_list->{'config'}{'listname'})) {
-                $log->syslog('err', 'Too long value of param "listname"');
-                push @{$self->{'errors'}{'create_list'}},
-                    $hash_list->{'config'}{'listname'};
-                next;
-            }
-
             ## Create the list
-            my $result = Sympa::Admin::create_list($hash_list->{'config'},
-                $self, $self->{'robot'});
-            unless (defined $result) {
+            my $spindle = Sympa::Spindle::ProcessRequest->new(
+                context          => $self,
+                action           => 'create_automatic_list',
+                listname         => $hash_list->{config}{listname},
+                parameters       => $hash_list->{config},
+                sender           => Sympa::get_address($self, 'listmaster'),
+                scenario_context => {skip => 1},
+            );
+            unless ($spindle and $spindle->spin and $spindle->success) {
                 push(
                     @{$self->{'errors'}{'create_list'}},
                     $hash_list->{'config'}{'listname'}
                 );
                 next;
             }
-            unless (defined $result->{'list'}) {
-                push(
-                    @{$self->{'errors'}{'create_list'}},
-                    $hash_list->{'config'}{'listname'}
-                );
-                next;
-            }
-            $list = $result->{'list'};
+            $list = Sympa::List->new($hash_list->{config}{listname},
+                $self->{'robot'});
 
             ## aliases
-            if ($result->{'aliases'} == 1) {
+            if (grep { $_->[1] eq 'notice' and $_->[2] eq 'auto_aliases' }
+                @{$spindle->{stash} || []}) {
                 push(
                     @{$self->{'created_lists'}{'with_aliases'}},
                     $list->{'name'}
                 );
-
             } else {
-                $self->{'created_lists'}{'without_aliases'}{$list->{'name'}}
-                    = $result->{'aliases'};
+                $self->{'created_lists'}{'without_aliases'}{$list->{'name'}} =
+                    $list->{'name'};
             }
 
             # config_changes
@@ -1074,15 +1025,16 @@ sub instantiate {
             #}
         }
         if ($options{close_unknown} or $answer eq 'y') {
-            unless (
-                $list->set_status_family_closed(
-                    'close_list', $self->{'name'}
-                )
-                ) {
-                push(
-                    @{$self->{'family_closed'}{'impossible'}},
-                    $list->{'name'}
-                );
+            my $spindle = Sympa::Spindle::ProcessRequest->new(
+                context          => $self->{'robot'},
+                action           => 'close_list',
+                current_list     => $list,
+                sender           => Sympa::get_address($self, 'listmaster'),
+                scenario_context => {skip => 1},
+            );
+            unless ($spindle and $spindle->spin and $spindle->success) {
+                push @{$self->{'family_closed'}{'impossible'}},
+                    $list->{'name'};
             }
             push(@{$self->{'family_closed'}{'ok'}}, $list->{'name'});
 
@@ -2088,8 +2040,7 @@ sub _update_existing_list {
     my $old_status     = $list->{'admin'}{'status'};
 
     ## list config family updating
-    my $result = Sympa::Admin::update_list($list, $hash_list->{'config'},
-        $self, $self->{'robot'});
+    my $result = $self->_update_list($list, $hash_list->{'config'});
     unless (defined $result) {
         $log->syslog('err', 'No object list resulting from updating list %s',
             $list->{'name'});
@@ -2160,15 +2111,12 @@ sub _update_existing_list {
 
     if ($result->{'aliases'} == 1) {
         push(@{$self->{'updated_lists'}{'aliases_ok'}}, $list->{'name'});
-
     } elsif ($result->{'install_remove'} eq 'install') {
         $self->{'updated_lists'}{'aliases_to_install'}{$list->{'name'}} =
-            $result->{'aliases'};
-
+            $list->{'name'};
     } else {
         $self->{'updated_lists'}{'aliases_to_remove'}{$list->{'name'}} =
-            $result->{'aliases'};
-
+            $list->{'name'};
     }
 
     ## config_changes
@@ -2396,19 +2344,19 @@ sub _set_status_changes {
         $list->{'admin'}{'status'} = 'open';
     }
 
-    ## aliases
+    # Aliases.
+    my $aliases = Sympa::Aliases->new(
+        Conf::get_robot_conf($list->{'domain'}, 'alias_manager'));
     if ($list->{'admin'}{'status'} eq 'open') {
         unless ($old_status eq 'open') {
             $result->{'install_remove'} = 'install';
-            $result->{'aliases'} = Sympa::Admin::install_aliases($list);
+            $result->{'aliases'} = ($aliases and $aliases->add($list));
         }
     }
-
-    if (   ($list->{'admin'}{'status'} eq 'pending')
-        && (($old_status eq 'open') || ($old_status eq 'error_config'))) {
+    if ($list->{'admin'}{'status'} eq 'pending'
+        and ($old_status eq 'open' or $old_status eq 'error_config')) {
         $result->{'install_remove'} = 'remove';
-        $result->{'aliases'} =
-            Sympa::Admin::remove_aliases($list, $self->{'robot'});
+        $result->{'aliases'} = ($aliases and $aliases->del($list));
     }
 
     ### subscribers
@@ -2696,94 +2644,12 @@ sub _load_param_constraint_conf {
     return $constraint;
 }
 
-sub create_automatic_list {
-    my $self     = shift;
-    my %param    = @_;
-    my $sender   = $param{'sender'};
-    my $listname = $param{'listname'};
-
-    unless ($self->is_allowed_to_create_automatic_lists(%param)) {
-        $log->syslog(
-            'err',
-            'Unconsistent scenario evaluation result for automatic list creation of list %s@%s by user %s',
-            $listname,
-            $self->{'robot'},
-            $sender
-        );
-        return undef;
-    }
-    my $result = $self->add_list({listname => $listname}, 1);
-
-    unless (defined $result->{'ok'}) {
-        my $details =
-               $result->{'string_error'}
-            || $result->{'string_info'}
-            || [];
-        $log->syslog('err',
-            'Failed to add a dynamic list to the family %s: %s',
-            $self->{'name'}, join(';', @{$details}));
-        return undef;
-    }
-    my $list = Sympa::List->new($listname, $self->{'robot'});
-    unless (defined $list) {
-        $log->syslog('err', 'Dynamic list %s could not be created',
-            $listname);
-        return undef;
-    }
-    return $list;
-}
+#Deprecated. Use Sympa::Request::Handler::create_automatic_list request handler.
+#sub create_automatic_list;
 
 # Returns 1 if the user is allowed to create lists based on the family.
-sub is_allowed_to_create_automatic_lists {
-    my $self  = shift;
-    my %param = @_;
-
-    my $auth_level = $param{'auth_level'};
-    my $sender     = $param{'sender'};
-    my $message    = $param{'message'};
-    my $listname   = $param{'listname'};
-
-    # check authorization
-    my $result = Sympa::Scenario::request_action(
-        $self->{'robot'},
-        'automatic_list_creation',
-        $auth_level,
-        {   'sender'             => $sender,
-            'message'            => $message,
-            'family'             => $self,
-            'automatic_listname' => $listname
-        }
-    );
-    my $r_action;
-    unless (defined $result) {
-        $log->syslog(
-            'err',
-            'Unable to evaluate scenario "automatic_list_creation" for family %s',
-            $self->{'name'}
-        );
-        return undef;
-    }
-
-    if (ref($result) eq 'HASH') {
-        $r_action = $result->{'action'};
-    } else {
-        $log->syslog(
-            'err',
-            'Unconsistent scenario evaluation result for automatic list creation in family %s',
-            $self->{'name'}
-        );
-        return undef;
-    }
-
-    unless ($r_action =~ /do_it/) {
-        $log->syslog('debug2',
-            'Automatic list creation refused to user %s for family %s',
-            $sender, $self->{'name'});
-        return undef;
-    }
-
-    return 1;
-}
+#Deprecated. Use Sympa::Request::Handler::create_automatic_list request handler.
+#sub is_allowed_to_create_automatic_lists;
 
 ## Handle exclusion table for family
 sub insert_delete_exclusion {
@@ -2828,7 +2694,17 @@ sub insert_delete_exclusion {
     return 1;
 }
 
-=pod 
+sub get_id {
+    my $self = shift;
+
+    return '' unless $self->{'name'} and $self->{'robot'};
+    return $self->{'name'} . '@' . $self->{'robot'};
+}
+
+1;
+__END__
+
+=encoding utf-8
 
 =head1 AUTHORS 
 
@@ -2841,5 +2717,3 @@ sub insert_delete_exclusion {
 =back 
 
 =cut
-
-1;
