@@ -31,6 +31,7 @@ use strict;
 use warnings;
 use base qw(Class::Singleton);
 
+use Encode qw();
 use Locale::Messages;
 use POSIX qw();
 
@@ -577,14 +578,18 @@ sub dgettext {
         return '8bit';
     }
 
-    return $msgid unless $self->{lang} and $self->{lang} ne 'en';
+    my $gettext_locale;
+    unless ($self->{lang} and $self->{lang} ne 'en') {
+        $gettext_locale = 'en_US';
+    } else {
+        $gettext_locale = $self->{locale};
 
-    ## Workaround for nb/nn.
-    my $locale = $self->{locale};
-    $locale =~ s/^(nb|nn)\b/${1}_NO/;
+        # Workaround for nb/nn.
+        $gettext_locale =~ s/^(nb|nn)\b/${1}_NO/;
+    }
 
     local %ENV;
-    $ENV{'LANGUAGE'} = $locale;
+    $ENV{'LANGUAGE'} = $gettext_locale;
     return Locale::Messages::dgettext($textdomain, $msgid);
 }
 
@@ -684,6 +689,7 @@ sub gettext_strftime {
         POSIX::setlocale(POSIX::LC_TIME(), $self->{locale_time});
     }
     my $ret = POSIX::strftime($format, @args);
+    Encode::_utf8_off($ret);
 
     POSIX::setlocale(POSIX::LC_TIME(), $orig_locale);
     return $ret;
