@@ -8,6 +8,9 @@
 # Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
 # 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
 # Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
+# Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
+# directory of this distribution and at
+# <https://github.com/sympa-community/sympa.git>.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -52,9 +55,11 @@ our %cpan_modules = (
     'CGI::Fast' => {
         required_version => '1.08',        # At least version with CGI 3.51
         package_name     => 'CGI-Fast',    # Module name as of 2.xx.
+        mandatory        => 1,
         'gettext_id' =>
             "WWSympa, Sympa's web interface can run as a FastCGI (i.e. a persistent CGI). If you install this module, you will also need to install FCGI module",
     },
+    # CGI::Util is included in CGI.
     'Class::Singleton' => {
         required_version => '1.03',
         package_name     => 'Class-Singleton',
@@ -185,6 +190,7 @@ our %cpan_modules = (
     'FCGI' => {
         required_version => '0.67',
         package_name     => 'CGI-Fast',    # Parent module name
+        mandatory        => 1,
         'gettext_id' =>
             "WWSympa, Sympa's web interface can run as a FastCGI (i.e. a persistent CGI). If you install this module, you will also need to install the associated FastCGI frontend, e.g. mod_fcgid for Apache.",
     },
@@ -347,7 +353,7 @@ our %cpan_modules = (
         required_version => '0.712',
         package_name     => 'SOAP-Lite',
         'gettext_id' =>
-            'required if you want to run the Sympa SOAP server that provides ML services via a "web service"',
+            'required if you want to run the Sympa SOAP server that provides mailing list services via a "web service"',
     },
     'Sys::Syslog' => {
         required_version => '0.03',
