@@ -222,14 +222,19 @@ sub get_id {
 
     join ';', map {
         my $val = $self->{$_};
-        if (ref $val) {
+        if (Scalar::Util::blessed($val) and $val->can('get_id')) {
             sprintf '%s=%s', $_, $val->get_id;
+        } elsif (ref $val eq 'HASH' and $_ eq 'request') {  #FIXME
+            sprintf '%s=<%s>', $_, get_id($val);
+        } elsif (ref $val) {
+            sprintf '%s=%s', $_, ref $val;
         } else {
             sprintf '%s=%s', $_, $val;
         }
         } grep {
         defined $self->{$_}
-        } qw(action context arc email reception visibility request error);
+        } qw(action context current_list listname arc mode email
+             reception visibility request error);
 }
 
 1;
