@@ -137,9 +137,14 @@ sub upgrade {
 
     ## Empty the admin_table entries and recreate them
     $log->syslog('notice', 'Rebuilding the admin_table...');
-    Sympa::List::delete_all_list_admin();
-    foreach my $list (@$all_lists) {
-        $list->sync_include_admin();
+
+    if ($all_lists and @$all_lists) {
+        foreach my $list (@$all_lists) {
+            $list->sync_include_admin;
+        }
+    } else {
+        # Prevent empty admin table (GH #71).
+        $log->syslog('notice', 'Skipping rebuild, no list config files found');
     }
 
     ## Migration to tt2
@@ -745,7 +750,6 @@ sub upgrade {
                     "$list->{'dir'}/subscribers");
 
                 $list->{'admin'}{'user_data_source'} = 'include2';
-                $list->{'total'} = 0;
 
                 ## Add users to the DB
                 $list->add_list_member(@users);
@@ -923,7 +927,6 @@ sub upgrade {
             'password_case'              => 'NO',
             'review_page_size'           => 'yes',
             'title'                      => 'NO',
-            'use_fast_cgi'               => 'yes',
             'use_html_editor'            => 'NO',
             'viewlogs_page_size'         => 'yes',
             'wws_path'                   => undef,
@@ -940,6 +943,7 @@ sub upgrade {
             'task_manager_pidfile' => 'No more used',
             'archived_pidfile'     => 'No more used',
             'bounced_pidfile'      => 'No more used',
+            'use_fast_cgi'         => 'No longer used', # 6.2.25b deprecated
         );
 
         ## Set language of new file content
