@@ -6,6 +6,9 @@
  * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
  * 2006, 2007, 2008, 2009, 2010, 2011 Comite Reseau des Universites
  * Copyright (c) 2011, 2012, 2013, 2014, 2015, 2016, 2017 GIP RENATER
+ * Copyright 2017 The Sympa Community. See the AUTHORS.md file at the top-level
+ * directory of this distribution and at
+ * <https://github.com/sympa-community/sympa.git>.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,10 +43,10 @@
 
 #define SMTPC_BUFSIZ (8192)
 
-#define SMTPC_ERR_SOCKET (-1)
-#define SMTPC_ERR_PROTOCOL (-2)
-#define SMTPC_ERR_SUBMISSION (-3)
-#define SMTPC_ERR_UNKNOWN (-4)
+#define SMTPC_ERR_SOCKET (255)
+#define SMTPC_ERR_PROTOCOL (254)
+#define SMTPC_ERR_SUBMISSION (253)
+#define SMTPC_ERR_UNKNOWN (252)
 
 #define SMTPC_7BIT (0)
 #define SMTPC_8BIT (1)
@@ -226,7 +229,7 @@ static int parse_options(int *argcptr, char ***argvptr)
 			return -1;
 		    }
 
-		    if (*p == ':' && ++p != '\0')
+		    if (*p == ':' && *(++p) != '\0')
 			options.servname = p;
 		    else if (*p != '\0') {
 			fprintf(stderr, "Malformed port \"%s\"\n", p);
@@ -269,7 +272,7 @@ static int parse_options(int *argcptr, char ***argvptr)
 			return -1;
 		    }
 
-		    if (*p == ':' && ++p != '\0')
+		    if (*p == ':' && *(++p) != '\0')
 			options.servname = p;
 		    else if (*p != '\0') {
 			fprintf(stderr, "Malformed port \"%s\"\n", p);
